==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/StyleSelectorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleSelectorDescription } from "./StyleSelectorDescription";
/**
 * @hidden
 */
var StyleSelectorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StyleSelectorDescriptionMetadata, _super);
    function StyleSelectorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StyleSelectorDescriptionMetadata.b = function (a) {
        if (StyleSelectorDescriptionMetadata.a == null) {
            StyleSelectorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StyleSelectorDescriptionMetadata.c(StyleSelectorDescriptionMetadata.a);
        }
        if (a.k(StyleSelectorDescriptionMetadata.a)) {
            return;
        }
        a.ab(StyleSelectorDescriptionMetadata.a);
    };
    StyleSelectorDescriptionMetadata.c = function (a) {
    };
    StyleSelectorDescriptionMetadata.d = function (a) {
        StyleSelectorDescriptionMetadata.b(a);
        a.ad("StyleSelector", function () { return new StyleSelectorDescription(); });
        a.ac("StyleSelector", StyleSelectorDescriptionMetadata.a);
    };
    StyleSelectorDescriptionMetadata.$t = markType(StyleSelectorDescriptionMetadata, 'StyleSelectorDescriptionMetadata');
    StyleSelectorDescriptionMetadata.a = null;
    return StyleSelectorDescriptionMetadata;
}(Base));
export { StyleSelectorDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/StyleSelectorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleSelectorDescription } from "./StyleSelectorDescription";
/**
 * @hidden
 */
var StyleSelectorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StyleSelectorDescriptionMetadata, _super);
    function StyleSelectorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StyleSelectorDescriptionMetadata.b = function (a) {
        if (StyleSelectorDescriptionMetadata.a == null) {
            StyleSelectorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StyleSelectorDescriptionMetadata.c(StyleSelectorDescriptionMetadata.a);
        }
        if (a.k(StyleSelectorDescriptionMetadata.a)) {
            return;
        }
        a.ac(StyleSelectorDescriptionMetadata.a);
    };
    StyleSelectorDescriptionMetadata.c = function (a) {
    };
    StyleSelectorDescriptionMetadata.d = function (a) {
        StyleSelectorDescriptionMetadata.b(a);
        a.ae("StyleSelector", function () { return new StyleSelectorDescription(); });
        a.ad("StyleSelector", StyleSelectorDescriptionMetadata.a);
    };
    StyleSelectorDescriptionMetadata.$t = markType(StyleSelectorDescriptionMetadata, 'StyleSelectorDescriptionMetadata');
    StyleSelectorDescriptionMetadata.a = null;
    return StyleSelectorDescriptionMetadata;
}(Base));
export { StyleSelectorDescriptionMetadata };
